aboutsummaryrefslogtreecommitdiffstats
path: root/src/mds-base.c
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-08-24 00:56:59 +0200
committerMattias Andrée <maandree@operamail.com>2014-08-24 00:56:59 +0200
commita750c1bfaad6887953db2c834456b4a0ed73e37e (patch)
tree4c884d71cc724e6314cd648587188b0f83e47e15 /src/mds-base.c
parentm + do not any assumtion of int typedefs (diff)
downloadmds-a750c1bfaad6887953db2c834456b4a0ed73e37e.tar.gz
mds-a750c1bfaad6887953db2c834456b4a0ed73e37e.tar.bz2
mds-a750c1bfaad6887953db2c834456b4a0ed73e37e.tar.xz
if the system is awesome enough to have sigupdate defined, use it instead of sigusr1
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to 'src/mds-base.c')
-rw-r--r--src/mds-base.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mds-base.c b/src/mds-base.c
index b2d1935..f676e66 100644
--- a/src/mds-base.c
+++ b/src/mds-base.c
@@ -595,8 +595,8 @@ static void commit_suicide(int signo)
*/
int trap_signals(void)
{
- /* Make the server update without all slaves dying on SIGUSR1. */
- fail_if (xsigaction(SIGUSR1, received_reexec) < 0);
+ /* Make the server update without all slaves dying on SIGUPDATE. */
+ fail_if (xsigaction(SIGUPDATE, received_reexec) < 0);
/* Implement clean exit on SIGTERM. */
fail_if (xsigaction(SIGTERM, received_terminate) < 0);